@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for iot-data service client
 
@@ -10,16 +11,16 @@ Usage::
     client: IoTDataPlaneClient = boto3.client("iot-data")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, IO, TYPE_CHECKING, Type, Union
+from typing import IO, Any, Dict, Type, Union
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_iot_data.type_defs import (
     DeleteThingShadowResponseTypeDef,
     GetThingShadowResponseTypeDef,
     UpdateThingShadowResponseTypeDef,
 )
 
-
 __all__ = ("IoTDataPlaneClient",)
 
 
